==> V01.80.zip: tweet_live-V01.80/web/jenkins/config.php <==
<?php
$config = array(
   	'hashtag'    => '#transmedia',
   	'date'   => '25.05.2012',
   	'heure'   => '19:00',
   	'place'   => 'Centre Pompidou, Grande Salle',

   	'title' => "Henry Jenkins, Transmedia 2.0",
	'abstract'   => "Parole à la crtique<br />Vendredi 25 mai 2012, 19H<br/>Grande Salle, Centre Pompidou, Paris",
   	'description'=> "
<p>
Pionnier des études sur les fans, théoricien célébré de la culture de la convergence, Henry Jenkins a repensé l’écosystème médiatique
à l’aune du tournant participatif, marqué par l’essor des productions transmédiatiques. Passée la phase utopiste, ces dernières s’inscrivent
dans un paysage de plus en plus diversifié, traversé par une même culture en réseau. Henry Jenkins en dévoilera les multiples logiques,
du <i>mainstream</i> aux productions indépendantes, en passant par les <i>serious games</i>.
</p><p>
<p>
Conférence d’Henry Jenkins organisée en coproduction avec la Sorbonne Nouvelle.
Avec le partenariat de Orange Transmedia Lab.
</p>",
   	'link' => 'http://www.univ-paris3.fr/jsp/fiche_actualite.jsp?CODE=1331637711181',
   	'keywords'   => 'Transmedia, Henry Jenkins, Jenkins, fans',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.univ-paris3.fr/' class='footerLink' target='_blank'>Université Sorbonne Nouvelle Paris 3</a>
    | <a href='http://www.centrepompidou.fr/' class='footerLink' target='_blank'>Centre National d'Art et de Culture Georges Pompidou</a>
    | <a href='http://www.transmedialab.org/' class='footerLink' target='_blank'>Orange Transmedia Lab</a>
   	| <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>Institut de Recherche et d'Innovation</a>",

    'client_visual' => 'images/live_screen.jpg',// 480 × 320 pixels
    
 	'head_logo' => 'images/head_logo.png', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slider.png', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive.jpg', // 270 × 150 pixels

 	'archive_title' => "WWW 2012",
 	'archive_description' => 'par <a href="http://www.univ-paris3.fr/" target="_blank">Univ. Sorbonne Nouvelle</a> au Centre Pompidou<br/>le 25 mai 2012',
 	'islive_embed' => 'jenkins_multilingual_embedcode', /* See ../traduction.php */
    // After the event
	'metadata'    => "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/5510ecc4-5565-11e1-ac23-00145ea49a02",
	'duration'   => 6640378,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
);

==> V01.82.zip: tweet_live-V01.82/web/jenkins/config.php <==
<?php
$config = array(
   	'hashtag'    => '#transmedia',
   	'date'   => '25.05.2012',
   	'heure'   => '19:00',
   	'place'   => 'Centre Pompidou, Grande Salle',

   	'title' => "Henry Jenkins, Transmedia 2.0",
	'abstract'   => "Parole à la critique<br />Vendredi 25 mai 2012, 19H<br/>Grande Salle, Centre Pompidou, Paris",
   	'description'=> "
<p>
Pionnier des études sur les fans, théoricien célébré de la culture de la convergence, Henry Jenkins a repensé l’écosystème médiatique
à l’aune du tournant participatif, marqué par l’essor des productions transmédiatiques. Passée la phase utopiste, ces dernières s’inscrivent
dans un paysage de plus en plus diversifié, traversé par une même culture en réseau. Henry Jenkins en dévoilera les multiples logiques,
du <i>mainstream</i> aux productions indépendantes, en passant par les <i>serious games</i>.
</p><p>
<p>
Conférence d’Henry Jenkins organisée en coproduction avec la Sorbonne Nouvelle.
Avec le partenariat de Orange Transmedia Lab.
</p>",
   	'link' => 'http://www.univ-paris3.fr/jsp/fiche_actualite.jsp?CODE=1331637711181',
   	'keywords'   => 'Transmedia, Henry Jenkins, Jenkins, fans',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.univ-paris3.fr/' class='footerLink' target='_blank'>Université Sorbonne Nouvelle Paris 3</a>
    | <a href='http://www.centrepompidou.fr/' class='footerLink' target='_blank'>Centre National d'Art et de Culture Georges Pompidou</a>
    | <a href='http://www.transmedialab.org/' class='footerLink' target='_blank'>Orange Transmedia Lab</a>
   	| <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>Institut de Recherche et d'Innovation</a>",

    'client_visual' => 'images/live_screen.jpg',// 480 × 320 pixels
    
 	'head_logo' => 'images/head_logo.png', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slider.png', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive.jpg', // 270 × 150 pixels

 	'archive_title' => "WWW 2012",
 	'archive_description' => 'par <a href="http://www.univ-paris3.fr/" target="_blank">Univ. Sorbonne Nouvelle</a> au Centre Pompidou<br/>le 25 mai 2012',
 	'islive_embed' => '<iframe src="http://epresence.univ-paris3.fr/1/embed.aspx?eventId=127&embedded=true&clickToGoHome=true&templateType=Live" width="{{width}}" height="{{height}}" frameborder="0"></iframe>',
    // After the event
	'metadata'    => "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/5510ecc4-5565-11e1-ac23-00145ea49a02",
	'duration'   => 6640378,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
);
